const webpack = require('webpack')
const merge = require('webpack-merge')
const webpackBase = require('./webpack.base.config')
const CopyWebpackPlugin = require('copy-webpack-plugin')
const appConfig = require('../utils/get-app-config')
const { projectPath, resolve } = require('../utils')
const { IS_BROWSER } = require('./env.config')

webpackBase.output.publicPath = '/'

const imagePath = appConfig.imagePath || 'images'

module.exports = merge(webpackBase, {
  cache: true,
  module: {
    rules: [
      {
        test: /\.(js|vue)$/,
        loader: 'eslint-loader',
        enforce: "pre",
        include: [resolve('client')],
        options: { // 这里的配置项参数将会被传递到 eslint 的 CLIEngine 
          formatter: require('eslint-friendly-formatter')
        }
      }
    ]
  },
  plugins: [
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"development"'
      },
    }),
    new CopyWebpackPlugin([
      {
        from: `${projectPath}/${imagePath}`,
        to: `${imagePath}`,
      },
    ]),
  ]
})